@@ -146,6 +146,47 @@ pub fn main() -> Result<()> {
     }
 
     match cmd {
+        #[cfg(feature = "gitoxide-core-tools-clean")]
+        Subcommands::Clean(crate::plumbing::options::clean::Command {
+            debug,
+            dry_run: _,
+            execute,
+            ignored,
+            precious,
+            directories,
+            pathspec,
+            repositories,
+            pathspec_matches_result,
+            skip_hidden_repositories,
+            find_untracked_repositories,
+        }) => prepare_and_run(
+            "clean",
+            trace,
+            verbose,
+            progress,
+            progress_keep_open,
+            None,
+            move |_progress, out, err| {
+                core::repository::clean(
+                    repository(Mode::Lenient)?,
+                    out,
+                    err,
+                    pathspec,
+                    core::repository::clean::Options {
+                        debug,
+                        format,
+                        execute,
+                        ignored,
+                        precious,
+                        directories,
+                        repositories,
+                        pathspec_matches_result,
+                        skip_hidden_repositories: skip_hidden_repositories.map(Into::into),
+                        find_untracked_repositories: find_untracked_repositories.into(),
+                    },
+                )
+            },
+        ),
         Subcommands::Status(crate::plumbing::options::status::Platform {
             statistics,
             submodules,
@@ -226,8 +267,8 @@ pub fn main() -> Result<()> {
                         add_paths: add_path,
                         prefix,
                         files: add_virtual_file
-                            .chunks(2)
-                            .map(|c| (c[0].to_owned(), c[1].clone()))
+                            .chunks_exact(2)
+                            .map(|c| (c[0].clone(), c[1].clone()))
                             .collect(),
                         format: format.map(|f| match f {
                             crate::plumbing::options::archive::Format::Internal => {
