@@ -78,9 +78,11 @@ pub struct Args {
 
 #[derive(Debug, clap::Subcommand)]
 pub enum Subcommands {
-    /// Subcommands for creating worktree archivs
+    /// Subcommands for creating worktree archives
     #[cfg(feature = "gitoxide-core-tools-archive")]
     Archive(archive::Platform),
+    #[cfg(feature = "gitoxide-core-tools-clean")]
+    Clean(clean::Command),
     /// Subcommands for interacting with commit-graphs
     #[clap(subcommand)]
     CommitGraph(commitgraph::Subcommands),
@@ -272,7 +274,6 @@ pub mod corpus {
 }
 
 pub mod config {
-
     use gix::bstr::BString;
 
     /// Print all entries in a configuration file or access other sub-commands
@@ -478,6 +479,68 @@ pub mod mailmap {
     }
 }
 
+#[cfg(feature = "gitoxide-core-tools-clean")]
+pub mod clean {
+    use gitoxide::shared::CheckPathSpec;
+    use gix::bstr::BString;
+
+    #[derive(Default, Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, clap::ValueEnum)]
+    pub enum FindRepository {
+        All,
+        #[default]
+        NonBare,
+    }
+
+    impl From<FindRepository> for gitoxide_core::repository::clean::FindRepository {
+        fn from(value: FindRepository) -> Self {
+            match value {
+                FindRepository::All => gitoxide_core::repository::clean::FindRepository::All,
+                FindRepository::NonBare => gitoxide_core::repository::clean::FindRepository::NonBare,
+            }
+        }
+    }
+
+    #[derive(Debug, clap::Parser)]
+    pub struct Command {
+        /// Print additional debug information to help understand decisions it made.
+        #[arg(long)]
+        pub debug: bool,
+        /// A dummy to easy with muscle-memory. This flag is assumed if provided or not, and has no effect.
+        #[arg(short = 'n', long)]
+        pub dry_run: bool,
+        /// Actually perform the operation, which deletes files on disk without chance of recovery.
+        #[arg(long, short = 'e')]
+        pub execute: bool,
+        /// Remove ignored (and expendable) files.
+        #[arg(long, short = 'x')]
+        pub ignored: bool,
+        /// Remove precious files.
+        #[arg(long, short = 'p')]
+        pub precious: bool,
+        /// Remove whole directories.
+        #[arg(long, short = 'd')]
+        pub directories: bool,
+        /// Remove nested repositories.
+        #[arg(long, short = 'r')]
+        pub repositories: bool,
+        /// Pathspec patterns are used to match the result of the dirwalk, not the dirwalk itself.
+        ///
+        /// Use this if there is trouble using wildcard pathspecs, which affect the directory walk
+        /// in reasonable, but often unexpected ways.
+        #[arg(long, short = 'm')]
+        pub pathspec_matches_result: bool,
+        /// Enter ignored directories to skip repositories contained within.
+        #[arg(long)]
+        pub skip_hidden_repositories: Option<FindRepository>,
+        /// What kind of repositories to find inside of untracked directories.
+        #[arg(long, default_value = "non-bare")]
+        pub find_untracked_repositories: FindRepository,
+        /// The git path specifications to list attributes for, or unset to read from stdin one per line.
+        #[clap(value_parser = CheckPathSpec)]
+        pub pathspec: Vec<BString>,
+    }
+}
+
 pub mod odb {
     #[derive(Debug, clap::Subcommand)]
     pub enum Subcommands {
@@ -628,6 +691,7 @@ pub mod revision {
             DiffOrGit,
         }
     }
+
     #[derive(Debug, clap::Subcommand)]
     #[clap(visible_alias = "rev", visible_alias = "r")]
     pub enum Subcommands {
@@ -798,7 +862,6 @@ pub mod index {
 }
 
 pub mod submodule {
-
     #[derive(Debug, clap::Parser)]
     pub struct Platform {
         #[clap(subcommand)]
