@@ -12,7 +12,7 @@ use std::{
 };
 
 pub use bstr;
-use bstr::{BStr, ByteSlice};
+use bstr::ByteSlice;
 use io_close::Close;
 pub use is_ci;
 pub use once_cell;
@@ -697,9 +697,9 @@ fn extract_archive(
 /// Transform a verbose parser errors from raw bytes into a `BStr` to make printing/debugging human-readable.
 pub fn to_bstr_err(
     err: winnow::error::ErrMode<winnow::error::TreeError<&[u8], winnow::error::StrContext>>,
-) -> winnow::error::TreeError<&BStr, winnow::error::StrContext> {
+) -> winnow::error::TreeError<&winnow::stream::BStr, winnow::error::StrContext> {
     let err = err.into_inner().expect("not a streaming parser");
-    err.map_input(ByteSlice::as_bstr)
+    err.map_input(winnow::stream::BStr::new)
 }
 
 fn family_name() -> &'static str {
